Crate feco3

source ·
FECo3 is a library for parsing .fec files from the US Federal Election Commission.

.fec files are binary files that contain campaign finance data. This library provides an efficient, flexible, stream-oriented parser for these files.

The parser takes a byte stream as input, which makes it flexible enough to parse files from a variety of sources, including local files, HTTP streams, or a custom source.

FECo3 includes a framework for writing the parsed data. Currently, the only supported output format is CSV, but the framework is designed to be extensible to other formats.

There are bindings for python available on the repo.

Re-exports

  • pub use crate::record::Record;

Modules

Structs

  • Summary information about the filing.
  • A FEC file, the core data structure of this crate.
  • The header of a FEC file.

Enums