pub struct Record {
pub record_code: String,
pub schema: RecordSchema,
pub values: Vec<Value>,
}Expand description
A parsed line of a .FEC file.
See https://github.com/NickCrews/feco3/wiki for more info
Fields
record_code: StringThe record type code that begins the line in the .fec file, eg “SA11”
schema: RecordSchemavalues: Vec<Value>May contain fewer or more values than the schema expects.
Implementations